AnimationButton class

Inheritance

Constructors

AnimationButton({Key? key, required IconData iconTarget, Color? targetColor = Colors.black, double? targetSize = 70, required VoidCallback onChanged, IconData animatedIcon = Icons.favorite, Color? iconColor = const Color(0xFFF5F5F5), double? size = 70, Duration? duration = const Duration(milliseconds: 500), Curve curve = Curves.easeInOut, double iconSize = 120})
const

Properties

animatedIcon IconData
final
curve Curve
final
duration Duration?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
iconSize double
final
iconTarget IconData
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
targetColor Color?
final
targetSize double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AnimationButtonState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited